package
Version:
v1.0.0
Opens a new window with list of versions in this module.
Published: Jan 21, 2025
License: MIT
Opens a new window with license information.
Imports: 8
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type ViacCreds struct {
Username string `json:"username"`
Password string `json:"password"`
}
type Wealth struct {
TotalValue float32 `json:"totalValue"`
TotalPerformance float32 `json:"totalPerformance"`
TotalReturn float32 `json:"totalReturn"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.